***************
Acknowledgments
***************

This open source software code was developed in part or in whole in the Human
Brain Project, funded from the European Union’s Horizon 2020 Framework
Programme for Research and Innovation under Specific Grant Agreements
No. 720270, No. 785907 and No. 945539 (Human Brain Project SGA1, SGA2 and
SGA3) and European Union 7th Framework Programme (FP7/2007-2013) under grant
agreement no. 604102 (Human Brain Project, HBP).
